@@ -22,7 +22,7 @@
 
 #include <mailtransportakonadi_export.h>
 
-#include <QtCore/QDateTime>
+#include <QDateTime>
 
 #include <attribute.h>
 
@@ -58,10 +58,10 @@ public:
     virtual ~DispatchModeAttribute();
 
     /* reimpl */
-    DispatchModeAttribute *clone() const Q_DECL_OVERRIDE;
-    QByteArray type() const Q_DECL_OVERRIDE;
-    QByteArray serialized() const Q_DECL_OVERRIDE;
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    DispatchModeAttribute *clone() const override;
+    QByteArray type() const override;
+    QByteArray serialized() const override;
+    void deserialize(const QByteArray &data) override;
 
     /**
       Returns the dispatch mode for the message.
