@@ -50,10 +50,10 @@ public:
     virtual ~TransportAttribute();
 
     /* reimpl */
-    TransportAttribute *clone() const Q_DECL_OVERRIDE;
-    QByteArray type() const Q_DECL_OVERRIDE;
-    QByteArray serialized() const Q_DECL_OVERRIDE;
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    TransportAttribute *clone() const override;
+    QByteArray type() const override;
+    QByteArray serialized() const override;
+    void deserialize(const QByteArray &data) override;
 
     /**
       Returns the transport id to use for sending this message.
